Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(250)

Unified Diff: third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h

Issue 2552343009: [Presentation API] Adds DOMString[] constructor to PresentationRequest. (Closed)
Patch Set: resolve code review comments from foolip Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h
diff --git a/third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h b/third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h
index 7caf880f7cad8ed5289d3c366de36e518989b66d..367996c2670a4bae93fc3d8172bf63b2703792bd 100644
--- a/third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h
+++ b/third_party/WebKit/Source/modules/presentation/PresentationAvailabilityCallbacks.h
@@ -10,6 +10,7 @@
#include "platform/weborigin/KURL.h"
#include "public/platform/WebCallbacks.h"
#include "wtf/Noncopyable.h"
+#include "wtf/Vector.h"
namespace blink {
@@ -17,12 +18,13 @@ struct WebPresentationError;
// PresentationAvailabilityCallback extends WebCallbacks to resolve the
// underlying promise depending on the result passed to the callback. It takes a
// KURL in its constructor and will pass it to the WebAvailabilityObserver.
class PresentationAvailabilityCallbacks final
: public WebCallbacks<bool, const WebPresentationError&> {
public:
PresentationAvailabilityCallbacks(PresentationAvailabilityProperty*,
- const KURL&);
+ const WTF::Vector<KURL>&);
~PresentationAvailabilityCallbacks() override;
void onSuccess(bool value) override;
@@ -30,7 +32,7 @@ class PresentationAvailabilityCallbacks final
private:
Persistent<PresentationAvailabilityProperty> m_resolver;
- const KURL m_url;
+ const WTF::Vector<KURL> m_urls;
WTF_MAKE_NONCOPYABLE(PresentationAvailabilityCallbacks);
};
@@ -17,12 +18,13 @@ struct WebPresentationError;
// PresentationAvailabilityCallback extends WebCallbacks to resolve the
// underlying promise depending on the result passed to the callback. It takes a
-// KURL in its constructor and will pass it to the WebAvailabilityObserver.
+// WTF::Vector<KURL> in its constructor and will pass it to the
+// WebAvailabilityObserver.
class PresentationAvailabilityCallbacks final
: public WebCallbacks<bool, const WebPresentationError&> {

Powered by Google App Engine
This is Rietveld 408576698